# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__PROJECT__ = 'tw.rating'
__DESCRIPTION__ = 'Star Rater plugin'
__URL__ = 'http://toscawidgets.org/'
__VERSION__ = '0.8'
__AUTHOR__ = "Christopher Perkins, Alberto Valverde, Sean O'Donnell"
__EMAIL__ = 'chris@percious.com'
__COPYRIGHT__ = "Copyright 2008 Alberto Valverde, Sean O'Donnell, Christopher Perins"
__LICENSE__ = 'MIT'
